==> distribution-6.19.3.zip: drr/regulation/common/trade/payment/reports/FloatingRateResetFrequencyPeriodLeg2Rule.java <==
package drr.regulation.common.trade.payment.reports;

import cdm.base.datetime.PeriodExtendedEnum;
import cdm.product.common.schedule.ResetFrequency;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.TransactionReportInstruction;
import drr.standards.iosco.cde.base.payment.functions.MapCDEFrequencyPeriod;
import drr.standards.iso.FrequencyPeriodEnum;
import javax.inject.Inject;


@ImplementedBy(FloatingRateResetFrequencyPeriodLeg2Rule.FloatingRateResetFrequencyPeriodLeg2RuleDefault.class)
public abstract class FloatingRateResetFrequencyPeriodLeg2Rule implements ReportFunction<TransactionReportInstruction, FrequencyPeriodEnum> {
	
	// RosettaFunction dependencies
	//
	@Inject protected FloatingRateResetFrequencyLeg2Rule floatingRateResetFrequencyLeg2Rule;
	@Inject protected MapCDEFrequencyPeriod mapCDEFrequencyPeriod;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public FrequencyPeriodEnum evaluate(TransactionReportInstruction input) {
		FrequencyPeriodEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract FrequencyPeriodEnum doEvaluate(TransactionReportInstruction input);

	public static class FloatingRateResetFrequencyPeriodLeg2RuleDefault extends FloatingRateResetFrequencyPeriodLeg2Rule {
		@Override
		protected FrequencyPeriodEnum doEvaluate(TransactionReportInstruction input) {
			FrequencyPeriodEnum output = null;
			return assignOutput(output, input);
		}
		
		protected FrequencyPeriodEnum assignOutput(FrequencyPeriodEnum output, TransactionReportInstruction input) {
			final MapperS<ResetFrequency> thenArg = MapperS.of(floatingRateResetFrequencyLeg2Rule.evaluate(input));
			output = thenArg
				.mapSingleToItem(item -> MapperS.of(mapCDEFrequencyPeriod.evaluate(item.<PeriodExtendedEnum>map("getPeriod", resetFrequency -> resetFrequency.getPeriod()).get()))).get();
			
			return output;
		}
	}
}

==> distribution-7.0.0-dev.17.zip: drr/regulation/common/trade/payment/reports/FloatingRateResetFrequencyPeriodLeg2Rule.java <==
package drr.regulation.common.trade.payment.reports;

import cdm.base.datetime.PeriodExtendedEnum;
import cdm.product.common.schedule.ResetFrequency;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.TransactionReportInstruction;
import drr.standards.iso.FrequencyPeriodEnum;
import drr.standards.iso.functions.ConvertPeriodtoISOFrequencyPeriod;
import javax.inject.Inject;


@ImplementedBy(FloatingRateResetFrequencyPeriodLeg2Rule.FloatingRateResetFrequencyPeriodLeg2RuleDefault.class)
public abstract class FloatingRateResetFrequencyPeriodLeg2Rule implements ReportFunction<TransactionReportInstruction, FrequencyPeriodEnum> {
	
	// RosettaFunction dependencies
	//
	@Inject protected ConvertPeriodtoISOFrequencyPeriod convertPeriodtoISOFrequencyPeriod;
	@Inject protected FloatingRateResetFrequencyLeg2Rule floatingRateResetFrequencyLeg2Rule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public FrequencyPeriodEnum evaluate(TransactionReportInstruction input) {
		FrequencyPeriodEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract FrequencyPeriodEnum doEvaluate(TransactionReportInstruction input);

	public static class FloatingRateResetFrequencyPeriodLeg2RuleDefault extends FloatingRateResetFrequencyPeriodLeg2Rule {
		@Override
		protected FrequencyPeriodEnum doEvaluate(TransactionReportInstruction input) {
			FrequencyPeriodEnum output = null;
			return assignOutput(output, input);
		}
		
		protected FrequencyPeriodEnum assignOutput(FrequencyPeriodEnum output, TransactionReportInstruction input) {
			final MapperS<ResetFrequency> thenArg = MapperS.of(floatingRateResetFrequencyLeg2Rule.evaluate(input));
			output = thenArg
				.mapSingleToItem(item -> MapperS.of(convertPeriodtoISOFrequencyPeriod.evaluate(item.<PeriodExtendedEnum>map("getPeriod", resetFrequency -> resetFrequency.getPeriod()).get()))).get();
			
			return output;
		}
	}
}
